# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("No selection to change case")
msg0002 = _("Selected text is already uppercase")
msg0003 = _("Changed selected text to uppercase")
msg0004 = _("Selected text is already lowercase")
msg0005 = _("Changed selected text to lowercase")
msg0006 = _("Selected text is already capitalized")
msg0007 = _("Capitalized selected text")
msg0008 = _("Swapped the case of selected text")
msg0009 = _("_Case")
msg0010 = _("_Uppercase")
msg0011 = _("_Lowercase")
msg0012 = _("_Titlecase")
msg0013 = _("_Swapcase")
